@@ -1,7 +1,10 @@
+import logging
 import random
 import shutil
 from pathlib import Path
 
+log = logging.getLogger("oeleo")
+
 
 def mock_mover(path: Path, to: Path, *args, **kwargs):
     print(f"COPYING {path} -> {to}")
@@ -10,12 +13,12 @@ def mock_mover(path: Path, to: Path, *args, **kwargs):
     return success
 
 
-def simple_mover(path: Path, to: Path, *args, **kwargs):
+def simple_mover(path: Path, to: Path, *args, **kwargs) -> bool:
     try:
         shutil.copyfile(path, to)
         return True
     except OSError:
-        print("Could not copy this file - destination most likely not writable!")
+        log.debug("Could not copy this file - destination most likely not writable!")
         return False
 
 
@@ -29,5 +32,5 @@ def connected_mover(path: Path, to: Path, connector=None, *args, **kwargs):
         success = move_func(path, to)
         return success
     except OSError:
-        print("Could not copy this file - destination most likely not writable!")
+        log.debug("Could not copy this file - destination most likely not writable!")
         return False
