@@ -120,7 +120,7 @@ class Worker(WorkerBase):
 
     def __post_init__(self):
         if self.dry_run:
-            log.debug("[bold red blink]DRY RUN[/]", extra={"markup": True})
+            log.debug("DRY RUN")
             self.bookkeeper = MockDbHandler()
         self.external_connector.connect()
 
@@ -132,7 +132,7 @@ class Worker(WorkerBase):
     def add_local(self, local_files: Iterable) -> List:
         """Add the files that should be processed."""
         if not isinstance(local_files, list):
-            logging.warning(
+            log.warning(
                 "Please provide a list for local files when using add_local. "
                 "If it is a generator, you will have to re-run "
                 "add_local before each call to check or run."
@@ -141,6 +141,7 @@ class Worker(WorkerBase):
         self.status = ("state", "filter-local")
         self.status = ("filtered_once", False)
         self.file_names = local_files
+        log.debug(f"Adding {len(local_files)} files to the worker")
         return local_files
 
     def filter_local(self, **kwargs):
@@ -151,6 +152,7 @@ class Worker(WorkerBase):
             self.extension, **kwargs
         )
         self.file_names = local_files
+        log.debug(f"Filtering files to the worker")
         return local_files
 
     def filter_external(self, **kwargs):
@@ -159,9 +161,10 @@ class Worker(WorkerBase):
         external_files = self.external_connector.base_filter_sub_method(
             self.extension, **kwargs
         )
+        log.debug(f"Filtering external files to the worker")
         return external_files
 
-    def check(self, update_db=False, force=False, **kwargs):
+    def check(self, update_db=False, force=True, **kwargs):
         """Check for differences between the two directories.
 
         Arguments:
@@ -174,7 +177,7 @@ class Worker(WorkerBase):
         """
 
         self.status = ("state", "check")
-        log.debug("****** CHECK:")
+        log.debug("<CHECK>")
         self.reporter.report(
             f"Comparing {self.local_connector.directory} <=> {self.external_connector.directory}"
         )
@@ -182,6 +185,7 @@ class Worker(WorkerBase):
 
         # cannot be a generator since we need to do a `if in` lookup:
         external_files = list(self.filter_external(**kwargs))
+        log.debug(f"Checking {len(external_files)} files")
 
         number_of_local_files = 0
         number_of_external_duplicates = 0
@@ -197,12 +201,12 @@ class Worker(WorkerBase):
             )
             if external_name in external_files:
                 self.reporter.report(
-                    f"[cyan]{f.name}[/cyan] -> [cyan]{self.external_name}[/cyan]"
+                    f"{f.name} -> {self.external_name}"
                 )
                 code = 1
                 exists = True
 
-                log.debug(f"[FOUND EXTERNAL]")
+                log.debug(f"FOUND EXTERNAL")
                 number_of_external_duplicates += 1
 
                 external_vals = self.checker.check(
@@ -219,17 +223,18 @@ class Worker(WorkerBase):
                         number_of_duplicates_out_of_sync += 1
                         code = 0
                         self.reporter.report(
-                            f"    (E) {k}: [red]{external_vals[k]}[/red]"
+                            f"    (E) {k}: {external_vals[k]}"
                         )
                     else:
                         self.reporter.report(
-                            f"    (E) {k}: [green]{external_vals[k]}[/green]"
+                            f"    (E) {k}: {external_vals[k]}"
                         )
                 log.debug(f"In sync: {same}")
 
             else:
+                number_of_duplicates_out_of_sync += 1
                 self.reporter.report(
-                    f"[cyan]{f.name}[/cyan] -> [red]{self.external_name}[/red]"
+                    f"{f.name} -> {self.external_name}"
                 )
                 exists = False
                 code = 0
@@ -242,12 +247,11 @@ class Worker(WorkerBase):
 
                     if not force and not exists:
                         code = self.bookkeeper.code
-
                     self.bookkeeper.update_record(
                         external_name, code=code, **local_vals
                     )
 
-        self.reporter.report("\n[green bold]REPORT (CHECK):[/green bold]")
+        self.reporter.report("\nREPORT (CHECK):")
         self.reporter.report(
             f"-Total number of local files:    {number_of_local_files}"
         )
@@ -257,11 +261,12 @@ class Worker(WorkerBase):
         self.reporter.report(
             f"-Files out of sync:              {number_of_duplicates_out_of_sync}"
         )
+        log.debug("<CHECK FINISHED>")
 
     def run(self):
         """Copy the files that needs to be copied and update the db."""
 
-        log.debug("****** RUN:")
+        log.debug("<RUN>")
         self.status = ("state", "run")
         local_files_found = False
         for f in self.file_names:
@@ -271,6 +276,7 @@ class Worker(WorkerBase):
             self.reporter.report(
                 "No files to handle. Did you forget to run `worker.filter_local()`?"
             )
+        log.debug("<RUN FINISHED>")
 
     def _process_file(self, f):
         del self.status
@@ -278,29 +284,33 @@ class Worker(WorkerBase):
         self.bookkeeper.register(f)
         checks = self.checker.check(f)
         if not self.bookkeeper.is_changed(**checks):
-            log.debug(f"{f} not changed")
-            self.reporter.report(
-                f":smiley: [green]{f.name}[/green] == [green]{self.external_name}[/green]"
+            log.debug(
+                f"{f.name} == {self.external_name}"
             )
+            self.reporter.report(" .", same_line=True)
+            return
+
+        log.debug(
+            f"{f.name} -> {self.external_name}"
+        )
+
+        self.status = ("changed", True)
+        if self.external_connector.move_func(
+            f,
+            self.external_name,
+        ):
+            self.status = ("moved", True)
+            self.bookkeeper.update_record(self.external_name, **checks)
+            self.reporter.report("o", same_line=True)
+            log.debug(
+                f"{f.name} -> {self.external_name} copied"
 
-        else:
-            self.reporter.report(
-                f":arrow_forward: [green]{f.name}[/green] -> [blue]{self.external_name}[/blue]"
             )
-            self.status = ("changed", True)
-            if self.external_connector.move_func(
-                f,
-                self.external_name,
-            ):
-                self.status = ("moved", True)
-                self.bookkeeper.update_record(self.external_name, **checks)
-                self.reporter.report(" :smiley:", same_line=True)
-            else:
-                self.reporter.report(
-                    f":warning: [green]{f.name}[/green] -> "
-                    f"[red]{self.external_name}[/red] :slightly_frowning_face: failed copy!",
-                    replace_line=True,
-                )
+        else:
+            self.reporter.report("!", same_line=True)
+            log.debug(
+                f"{f.name} -> {self.external_name} FAILED COPY!"
+            )
 
     def _default_external_name_generator(self, f):
         return self.external_connector.directory / f.name
@@ -359,6 +369,11 @@ def simple_worker(
 
     Returns:
         simple worker that can copy files between two local folder.
+
+    Usage:
+        >>> my_oeleo = simple_worker()  # reads necessary settings from .env or ENVs as default.
+        >>> my_oeleo.filter_local()  # or my_oeleo.add_local(["file1.csv", "file2.csv"])
+        >>> my_oeleo.run()
     """
     db_name = db_name or os.environ["OELEO_DB_NAME"]
     base_directory_from = base_directory_from or os.environ["OELEO_BASE_DIR_FROM"]
@@ -368,12 +383,12 @@ def simple_worker(
     checker = ChecksumChecker()
     local_connector = LocalConnector(directory=base_directory_from)
     external_connector = LocalConnector(directory=base_directory_to)
-
+    log.debug("<Simple Worker created>")
     log.debug(
-        f"[bold]from:[/] [bold green]{base_directory_from}[/]", extra={"markup": True}
+        f"from:{base_directory_from}"
     )
     log.debug(
-        f"[bold]to  :[/] [bold blue]{base_directory_to}[/]", extra={"markup": True}
+        f"to  :{base_directory_to}"
     )
 
     worker = Worker(
@@ -388,8 +403,8 @@ def simple_worker(
 
 
 def ssh_worker(
-    base_directory_from: Union[str, None] = None,
-    base_directory_to: Union[str, None] = None,
+    base_directory_from: Union[str, None, Path] = None,
+    base_directory_to: Union[str, None, Path] = None,
     db_name: Union[str, None] = None,
     extension: str = None,
     use_password: bool = False,
@@ -424,13 +439,13 @@ def ssh_worker(
     bookkeeper = SimpleDbHandler(db_name)
     checker = ChecksumChecker()
 
+    log.debug("<SSH Worker created>")
+
     log.debug(
-        f"[bold]from:[/] [bold green]{local_connector.directory}[/]",
-        extra={"markup": True},
+        f"from:{local_connector.directory}"
     )
     log.debug(
-        f"[bold]to  :[/] [bold blue]{external_connector.host}:{external_connector.directory}[/]",
-        extra={"markup": True},
+        f"to  :{external_connector.host}:{external_connector.directory}"
     )
 
     worker = Worker(
@@ -471,10 +486,6 @@ def sharepoint_worker(
     def external_name_generator(con, name):
         return Path(name.name)
 
-    log.setLevel(logging.DEBUG)
-    log.debug(f"Starting oeleo!")
-    console.print(f"Starting oeleo!")
-
     db_name = db_name or os.environ["OELEO_DB_NAME"]
 
     base_directory_from = base_directory_from or os.environ["OELEO_BASE_DIR_FROM"]
@@ -496,14 +507,13 @@ def sharepoint_worker(
 
     bookkeeper = SimpleDbHandler(db_name)
     checker = ChecksumChecker()
+    log.debug("<SSH Worker created>")
 
     log.debug(
-        f"[bold]from:[/] [bold green]{local_connector.directory}[/]",
-        extra={"markup": True},
+        f"from: {local_connector.directory}"
     )
     log.debug(
-        f"[bold]to  :[/] [bold blue]{external_connector.url}:{external_connector.directory}[/]",
-        extra={"markup": True},
+        f"to  :{external_connector.url}:{external_connector.directory}"
     )
 
     worker = Worker(
